__version__ = '0.1.0'


""" Top level package for the detect_and_display """

__author__ = """ Patricio Tula and Agustin Tedesco """
__version__ = '0.1.0'

from detect_and_display.detect_and_display import DetectAndDisplay

__all__ = ['DetectAndDisplay']



import threading


class Singleton(type):
    """Metaclass to create a Singleton."""

    _instance = {}
    _lock = threading.Lock()

    def __call__(cls, *args, **kwargs):
        if cls not in Singleton._instance:
            with Singleton._lock:
                Singleton._instance.setdefault(cls, super().__call__(*args, **kwargs))
        return Singleton._instance[cls]



import click

from detect_and_display_cli.detect_and_display_cli import pass_context


@click.group()
@click.version_option()
def cli():
    """Manages Display."""

@cli.command('text')
@click.argument('input')
@pass_context
def display(ctx, input):
    """Display text into screen."""
    ctx.log(ctx.service.display(input))


import logging

from detect_and_display.utils.singleton import Singleton


class DetectAndDisplayLogger(metaclass=Singleton):
    """Logger of the module."""
    def __init__(self):
        self._logger = logging.getLogger('detect-and-display')
        self._logger.setLevel(logging.DEBUG)
        formatter = logging.Formatter('%(asctime)s - %(module)s%(funcName)s - %(levelname)s - %(message)s')
        console_handler = logging.StreamHandler()
        console_handler.setLevel(logging.DEBUG)
        console_handler.setFormatter(formatter)
        self._logger.addHandler(console_handler)

    def get_logger(self):
        """Get logger"""
        return self._logger



import os
import sys
import click
import logging

from pathlib import Path

from detect_and_display.utils.detect_and_display_logger import DetectAndDisplayLogger
from detect_and_display import DetectAndDisplay


CONTEXT_SETTINGS = dict(auto_envvar_prefix='DETECTANDDISPLAY')


class Context(object):

    def __init__(self):
        self.verbose = False
        self.config_dir = str(Path.home())
        self.service = None
        self.logger = DetectAndDisplayLogger().get_logger()

    def log(self, msg, *args):
        """Logs a message to stderr."""
        if args:
            msg %= args
        click.echo(msg, file=sys.stderr)
    
    def vlog(self, msg, *args):
        """Logs a message to stderr only if verbose is enabled."""
        if self.verbose:
            self.log(msg, *args)

pass_context = click.make_pass_decorator(Context, ensure=True)
cmd_folder = os.path.abspath(os.path.join(os.path.dirname(__file__), 'commands'))


class DetectAndDisplayCLI(click.MultiCommand):

    def list_commands(self, ctx):
        commands = []
        for filename in os.listdir(cmd_folder):
            if filename.endswith('.py') and filename.startswith('cmd_'):
                commands.append(filename[4:-3])
        commands.sort()
        return commands

    def get_command(self, ctx, name):
        try:
            if sys.version_info[0] == 2:
                name = name.encode('ascii', 'replace')
            mod = __import__(f'detect_and_display_cli.commands.cmd_{name}', None, None, ['cli'])
        except ImportError as err:
            DetectAndDisplayLogger().get_logger().error(err)
            return
        return mod.cli


@click.command(cls=DetectAndDisplayCLI, context_settings=CONTEXT_SETTINGS)
@click.option('-v', '--verbose', is_flag=True, default=False, help='Enables verbose mode.')
@pass_context
def cli(ctx, verbose):
    """DetectAndDisplay command line interface."""
    if verbose is False:
        ctx.logger.setLevel(logging.NOTSET)
    else:
        ctx.logger.setLevel(logging.INFO)
    
    ctx.service = DetectAndDisplay()


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['detect_and_display',
 'detect_and_display.utils',
 'detect_and_display_cli',
 'detect_and_display_cli.commands']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.1,<9.0.0']

entry_points = \
{'console_scripts': ['detect-and-display = '
                     'detect_and_display_cli.detect_and_display_cli:cli']}

setup_kwargs = {
    'name': 'detect-and-display',
    'version': '0.1.1',
    'description': '',
    'long_description': None,
    'author': 'patricio tula',
    'author_email': 'tula.patricio@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



class DetectAndDisplay:
    """Class that encapsulates the detection and display of license plates."""
    def display(self, text: str) -> None:
        """Display the text"""
        return f'the screen is displaying: {text}'
